@@ -53,10 +53,10 @@ Demo gnomedb_demos[] = {
   { "DDL queries", "ddl_queries.c", do_ddl_queries, NULL }, 
   { "Data models", NULL, NULL, child0 }, 
   { "Data widgets linking", NULL, NULL, child3 }, 
-  { "Dictionary browser", "selector.c", do_selector, NULL }, 
   { "Forms", NULL, NULL, child1 }, 
   { "Graph", "graph.c", do_graph, NULL }, 
   { "Grids", NULL, NULL, child2 }, 
+  { "Metadata browser", "selector.c", do_selector, NULL }, 
   { "Sql console", "console.c", do_console, NULL },
   { NULL } 
 };
