@@ -2,17 +2,17 @@
  *
  * Copyright (C) 2002 - 2006 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Library General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -21,6 +21,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
+#include "gnome-db-enums.h"
 #include "gnome-db-basic-form.h"
 #include "gnome-db-tools.h"
 #include "marshal.h"
@@ -48,8 +49,8 @@ static void gnome_db_basic_form_clean (GnomeDbBasicForm *form);
 
 static void get_rid_of_set (GdaSet *paramlist, GnomeDbBasicForm *form);
 static void paramlist_public_data_changed_cb (GdaSet *paramlist, GnomeDbBasicForm *form);
-static void paramlist_param_plugin_changed_cb (GdaSet *paramlist, GdaHolder *param, GnomeDbBasicForm *form);
-static void paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param, GnomeDbBasicForm *form);
+static void paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param, 
+					     const gchar *att_name, const GValue *att_value, GnomeDbBasicForm *form);
 
 static void entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form);
 static void entry_contents_activated (GnomeDbDataEntry *entry, GnomeDbBasicForm *form);
@@ -132,6 +133,14 @@ gnome_db_basic_form_class_init (GnomeDbBasicFormClass * class)
 	parent_class = g_type_class_peek_parent (class);
 
 	/* signals */
+	/**
+	 * GnomeDbBasicForm::param-changed:
+	 * @form: GnomeDbBasicForm
+	 * @param: that changed
+	 * @is_user_modif: TRUE if the modification has been initiated by a user modification
+	 *
+	 * Emitted when a GdaHolder changes
+	 */
 	gnome_db_basic_form_signals[PARAM_CHANGED] =
 		g_signal_new ("param_changed",
 			      G_TYPE_FROM_CLASS (object_class),
@@ -294,8 +303,6 @@ get_rid_of_set (GdaSet *paramlist, GnomeDbBasicForm *form)
 	/* unref the paramlist */
 	g_signal_handlers_disconnect_by_func (paramlist,
 					      G_CALLBACK (paramlist_public_data_changed_cb), form);
-	g_signal_handlers_disconnect_by_func (paramlist,
-					      G_CALLBACK (paramlist_param_plugin_changed_cb), form);
 	g_signal_handlers_disconnect_by_func (paramlist,
 					      G_CALLBACK (paramlist_param_attr_changed_cb), form);
 
@@ -319,41 +326,62 @@ paramlist_public_data_changed_cb (GdaSet *paramlist, GnomeDbBasicForm *form)
 }
 
 static void
-paramlist_param_plugin_changed_cb (GdaSet *paramlist, GdaHolder *param, GnomeDbBasicForm *form)
-{
-	/* TODO: be more specific and change only the entry corresponding to @param */
-	paramlist_public_data_changed_cb (paramlist, form);
-}
-
-static void
-paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param, GnomeDbBasicForm *form)
+paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param, 
+				 const gchar *att_name, const GValue *att_value, GnomeDbBasicForm *form)
 {
 	GtkWidget *entry;
 
-	entry = gnome_db_basic_form_get_entry_widget (form, param);
-	if (entry) {
-		gboolean toset;
-		guint attrs = 0;
-		guint mask = 0;
-		const GValue *defv;
+	if (!strcmp (att_name, GDA_ATTRIBUTE_IS_DEFAULT)) {
+		entry = gnome_db_basic_form_get_entry_widget (form, param);
+		if (entry) {
+			gboolean toset;
+			guint attrs = 0;
+			guint mask = 0;
+			const GValue *defv;
+			
+			defv = gda_holder_get_default_value (param);
+			attrs |= defv ? GDA_VALUE_ATTR_CAN_BE_DEFAULT : 0;
+			mask |= GDA_VALUE_ATTR_CAN_BE_DEFAULT;
+			
+			toset = gda_holder_get_not_null (param);
+			attrs |= toset ? 0 : GDA_VALUE_ATTR_CAN_BE_NULL;
+			mask |= GDA_VALUE_ATTR_CAN_BE_NULL;
+			
+			g_object_get (G_OBJECT (param), "use-default-value", &toset, NULL);
+			attrs |= toset ? GDA_VALUE_ATTR_IS_DEFAULT : 0;
+			mask |= GDA_VALUE_ATTR_IS_DEFAULT;
+			
+			g_signal_handlers_block_by_func (G_OBJECT (entry),
+							 G_CALLBACK (entry_contents_modified), form);
+			gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry), attrs, mask);
+			g_signal_handlers_unblock_by_func (G_OBJECT (entry),
+							   G_CALLBACK (entry_contents_modified), form);
+		}
+	}
+	else if (!strcmp (att_name, GNOME_DB_ATTRIBUTE_PLUGIN)) {
+		/* TODO: be more specific and change only the cell renderer corresponding to @param */
 
-		defv = gda_holder_get_default_value (param);
-		attrs |= defv ? GDA_VALUE_ATTR_CAN_BE_DEFAULT : 0;
-		mask |= GDA_VALUE_ATTR_CAN_BE_DEFAULT;
+		/* keep a list of hidden columns */
+		GSList *list, *hidden_params = NULL;
+		for (list = form->priv->hidden_entries; list; list = list->next) {
+			GdaHolder *param = g_object_get_data (G_OBJECT (list->data), "param");
+			if (param)
+				hidden_params = g_slist_prepend (hidden_params, param);
+			else {
+				/* multiple parameters, take the 1st param */
+				GdaSetGroup *group;				
+				group = g_object_get_data (G_OBJECT (list->data), "group");
+				hidden_params = g_slist_prepend (hidden_params, GDA_SET_NODE (group->nodes->data)->holder);
+			}
+		}
 
-		toset = gda_holder_get_not_null (param);
-		attrs |= toset ? 0 : GDA_VALUE_ATTR_CAN_BE_NULL;
-		mask |= GDA_VALUE_ATTR_CAN_BE_NULL;
+		/* re-create entries */
+		paramlist_public_data_changed_cb (paramlist, form);
 
-		g_object_get (G_OBJECT (param), "use-default-value", &toset, NULL);
-		attrs |= toset ? GDA_VALUE_ATTR_IS_DEFAULT : 0;
-		mask |= GDA_VALUE_ATTR_IS_DEFAULT;
-
-		g_signal_handlers_block_by_func (G_OBJECT (entry),
-						 G_CALLBACK (entry_contents_modified), form);
-		gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry), attrs, mask);
-		g_signal_handlers_unblock_by_func (G_OBJECT (entry),
-						   G_CALLBACK (entry_contents_modified), form);
+		/* hide entries which were hidden */
+		for (list = hidden_params; list; list = list->next) 
+			gnome_db_basic_form_entry_show (form, GDA_HOLDER (list->data), FALSE);
+		g_slist_free (hidden_params);
 	}
 }
 
@@ -490,9 +518,7 @@ gnome_db_basic_form_set_property (GObject *object,
 				g_object_ref (form->priv->set);
 				g_signal_connect (form->priv->set, "public_data_changed",
 						  G_CALLBACK (paramlist_public_data_changed_cb), form);
-				g_signal_connect (form->priv->set, "holder_plugin_changed",
-						  G_CALLBACK (paramlist_param_plugin_changed_cb), form);
-				g_signal_connect (form->priv->set, "holder_attr_changed",
+				g_signal_connect (form->priv->set, "holder-attr-changed",
 						  G_CALLBACK (paramlist_param_attr_changed_cb), form);
 
 #ifdef HAVE_LIBGLADE
@@ -640,7 +666,8 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 			GType type;
 			const GValue *val, *default_val, *value;
 			gboolean nnul;
-			gchar *plugin = NULL;
+			const gchar *plugin = NULL;
+			const GValue *plugin_val;
 
 			g_assert (g_slist_length (group->nodes) == 1);
 
@@ -658,10 +685,15 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 				value = default_val;
 			
 			/* create entry */
-			g_object_get (G_OBJECT (param), "plugin", &plugin, NULL);
+			plugin_val = gda_holder_get_attribute (param, GNOME_DB_ATTRIBUTE_PLUGIN);
+			if (plugin_val) {
+				if (G_VALUE_TYPE (plugin_val) == G_TYPE_STRING)
+					plugin = g_value_get_string (plugin_val);
+				else
+					g_warning (_("The '%s' attribute should be a G_TYPE_STRING value"),
+						   GNOME_DB_ATTRIBUTE_PLUGIN);
+			}
 			entry = GTK_WIDGET (gnome_db_util_new_data_entry (type, plugin));
-			g_free(plugin);
-
 
 			/* set current value */
 			gnome_db_data_entry_set_value (GNOME_DB_DATA_ENTRY (entry), val);
@@ -705,8 +737,7 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 			g_signal_connect (entry, "destroy", G_CALLBACK (entry_destroyed_cb), form);
 
 			/* connect to the parameter's changes */
-			plist = group->nodes;
-			while (plist) {
+			for (plist = group->nodes; plist; plist = plist->next) {
 				GdaHolder *param;
 
 				param = GDA_SET_NODE (plist->data)->holder;
@@ -716,7 +747,6 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
                                                                               G_CALLBACK (parameter_changed_cb), 
 									      entry);
                                 i++;
-				plist = g_slist_next (plist);
 			}
 			gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (entry),
 							    nnul ? 0 : GDA_VALUE_ATTR_CAN_BE_NULL,
@@ -914,23 +944,6 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 	gnome_db_basic_form_show_entry_actions (form, form->priv->show_actions);
 	/* Set the Auto entries default in the entries */
 	gnome_db_basic_form_set_entries_auto_default (form, form->priv->entries_auto_default);
-
-	/* hide some entries if specified */
-	for (list = form->priv->entries; list; list = list->next) {
-		gboolean explicit_hide = FALSE;
-		GdaHolder *param;
-			
-		param = g_object_get_data (G_OBJECT (list->data), "param");
-		if (param) {
-			if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (param), "_gnome_db_explicit_show")) == 1)
-				explicit_hide = TRUE;
-		}
-		else {
-			/* FIXME */
-		}
-		if (explicit_hide) 
-			gnome_db_basic_form_entry_show (form, param, FALSE);
-	}
 }
 
 static void
@@ -1015,15 +1028,17 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 		if ((!value || gda_value_is_null (value)) &&
 		    (attr & GDA_VALUE_ATTR_IS_DEFAULT))
 			gda_holder_set_value_to_default (param);
+		else if (gda_holder_set_value (param, value, NULL)) {
+#ifdef debug_signal
+			g_print (">> 'PARAM_CHANGED' from %s\n", __FUNCTION__);
+#endif
+			g_signal_emit (G_OBJECT (form), gnome_db_basic_form_signals[PARAM_CHANGED], 0, param, TRUE);
+#ifdef debug_signal
+			g_print ("<< 'PARAM_CHANGED' from %s\n", __FUNCTION__);
+#endif
+		}
 		else
-			gda_holder_set_value (param, value);
-#ifdef debug_signal
-		g_print (">> 'PARAM_CHANGED' from %s\n", __FUNCTION__);
-#endif
-		g_signal_emit (G_OBJECT (form), gnome_db_basic_form_signals[PARAM_CHANGED], 0, param, TRUE);
-#ifdef debug_signal
-		g_print ("<< 'PARAM_CHANGED' from %s\n", __FUNCTION__);
-#endif
+			TO_IMPLEMENT;
 		gda_value_free (value);
 	}
 	else { /* multiple parameters */
@@ -1052,15 +1067,18 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 
 			/* parameter's value */
 			param = GDA_SET_NODE (params->data)->holder;
-			gda_holder_set_value (param, (GValue *)(list->data));
+			if (gda_holder_set_value (param, (GValue *)(list->data), NULL)) {
 #ifdef debug_signal
-			g_print (">> 'PARAM_CHANGED' from %s\n", __FUNCTION__);
+				g_print (">> 'PARAM_CHANGED' from %s\n", __FUNCTION__);
 #endif
-			g_signal_emit (G_OBJECT (form), gnome_db_basic_form_signals[PARAM_CHANGED], 
-				       0, param, TRUE);
+				g_signal_emit (G_OBJECT (form), gnome_db_basic_form_signals[PARAM_CHANGED], 
+					       0, param, TRUE);
 #ifdef debug_signal
-			g_print ("<< 'PARAM_CHANGED' from %s\n", __FUNCTION__);
+				g_print ("<< 'PARAM_CHANGED' from %s\n", __FUNCTION__);
 #endif
+			}
+			else
+				TO_IMPLEMENT;
 			form->priv->forward_param_updates = TRUE;
 
 			list = g_slist_next (list);
@@ -1209,8 +1227,7 @@ gnome_db_basic_form_set_current_as_orig (GnomeDbBasicForm *form)
 	g_return_if_fail (form && GNOME_DB_IS_BASIC_FORM (form));
 	g_return_if_fail (form->priv);
 
-	list = form->priv->entries;
-	while (list) {
+	for (list = form->priv->entries; list; list = list->next) {
 		GdaSetGroup *group;
 
 		group = g_object_get_data (G_OBJECT (list->data), "group");
@@ -1242,9 +1259,12 @@ gnome_db_basic_form_set_current_as_orig (GnomeDbBasicForm *form)
 		else {
 			/* non combo entry */
 			param = g_object_get_data (G_OBJECT (list->data), "param");
+			g_signal_handlers_block_by_func (G_OBJECT (list->data),
+							 G_CALLBACK (entry_contents_modified), form);
 			gnome_db_data_entry_set_value_orig (GNOME_DB_DATA_ENTRY (list->data), gda_holder_get_value (param));
+			g_signal_handlers_unblock_by_func (G_OBJECT (list->data),
+							   G_CALLBACK (entry_contents_modified), form);
 		}
-		list = g_slist_next (list);
 	}
 }
 
@@ -1262,7 +1282,7 @@ gnome_db_basic_form_is_valid (GnomeDbBasicForm *form)
 	g_return_val_if_fail (form && GNOME_DB_IS_BASIC_FORM (form), FALSE);
 	g_return_val_if_fail (form->priv, FALSE);
 
-	return gda_set_is_valid (form->priv->set);
+	return gda_set_is_valid (form->priv->set, NULL);
 }
 
 /**
@@ -1473,7 +1493,7 @@ gnome_db_basic_form_entry_grab_focus (GnomeDbBasicForm *form, GdaHolder *param)
  * gnome_db_basic_form_entry_set_editable
  * @form: a #GnomeDbBasicForm widget
  * @param: a #GdaHolder object
- * @editable:
+ * @editable: %TRUE if corresponding data entry must be editable
  *
  * Sets the #GnomeDbDataEntry in @form which corresponds to the
  * @param parameter editable or not
@@ -1571,8 +1591,7 @@ gnome_db_basic_form_get_entry_widget (GnomeDbBasicForm *form, GdaHolder *param)
 	g_return_val_if_fail (GNOME_DB_IS_BASIC_FORM (form), NULL);
 	g_return_val_if_fail (form->priv, NULL);
 
-	entries = form->priv->entries;
-	while (entries && !entry) {
+	for (entries = form->priv->entries; entries && !entry; entries = entries->next) {
 		GdaHolder *thisparam = g_object_get_data (G_OBJECT (entries->data), "param");
 
 		if (thisparam) {
@@ -1585,15 +1604,13 @@ gnome_db_basic_form_get_entry_widget (GnomeDbBasicForm *form, GdaHolder *param)
 			GdaSetGroup *group;
 
 			group = g_object_get_data (G_OBJECT (entries->data), "group");
-			params = group->nodes;
-			while (params && !entry) {
-				if (GDA_SET_NODE (params->data)->holder == (gpointer) param)
+			for (params = group->nodes; params; params = params->next) {
+				if (GDA_SET_NODE (params->data)->holder == (gpointer) param) {
 					entry = GTK_WIDGET (entries->data);
-				params = g_slist_next (params);
+					break;
+				}
 			}
 		}
-
-		entries = g_slist_next (entries);
 	}
 
 	return entry;
