@@ -2,17 +2,17 @@
  *
  * Copyright (C) 2002 - 2006 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Library General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -86,14 +86,14 @@ void              gnome_db_basic_form_entry_show               (GnomeDbBasicForm
 								GdaHolder *param, gboolean show);
 void              gnome_db_basic_form_entry_grab_focus         (GnomeDbBasicForm *form, GdaHolder *param);
 void              gnome_db_basic_form_entry_set_editable       (GnomeDbBasicForm *form, GdaHolder *param, 
-								gboolean sensitive);
+								gboolean editable);
 void              gnome_db_basic_form_set_entries_auto_default (GnomeDbBasicForm *form, gboolean auto_default);
 void              gnome_db_basic_form_set_entries_default      (GnomeDbBasicForm *form);
 
 GtkWidget        *gnome_db_basic_form_get_entry_widget         (GnomeDbBasicForm *form, GdaHolder *param);
 GtkWidget        *gnome_db_basic_form_get_label_widget         (GnomeDbBasicForm *form, GdaHolder *param);
 
-void              gnome_db_basic_form_entry_set_editable       (GnomeDbBasicForm *form, GdaHolder *param, gboolean editable);
+
 
 G_END_DECLS
 
