@@ -49,7 +49,7 @@ enum {
 };
 
 struct _GnomeDbDsnAssistantPrivate {
-	GdaDataSourceInfo  *dsn_info;
+	GdaDsnInfo  *dsn_info;
 	GdaServerOperation *create_db_op;
 
 	GdkPixbuf *logo;
@@ -89,7 +89,7 @@ static guint config_assistant_signals[LAST_SIGNAL] = { 0, };
 static GObjectClass *parent_class = NULL;
 
 static void 
-data_source_info_free (GdaDataSourceInfo *info)
+data_source_info_free (GdaDsnInfo *info)
 {
 	g_free (info->provider); 
 	g_free (info->cnc_string); 
@@ -137,7 +137,7 @@ assistant_applied_cb (GtkAssistant *assist, gpointer data)
 			GSList *dsn_params;
 			GError *error = NULL;
 
-			allok = gda_perform_create_database (assistant->priv->create_db_op, &error);
+			allok = gda_perform_create_database (NULL, assistant->priv->create_db_op, &error);
 			if (!allok) {
 				gchar *str;
 				str = g_strdup_printf (_("Error creating database: %s"), 
@@ -182,7 +182,7 @@ assistant_applied_cb (GtkAssistant *assist, gpointer data)
 
 	/* Data source declaration */
 	if (allok) {
-		assistant->priv->dsn_info = g_new0 (GdaDataSourceInfo, 1);
+		assistant->priv->dsn_info = g_new0 (GdaDsnInfo, 1);
 		assistant->priv->dsn_info->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (assistant->priv->general_name)));
 		assistant->priv->dsn_info->provider = g_strdup (
 					 gnome_db_provider_selector_get_provider (
@@ -299,7 +299,7 @@ dsn_name_changed_cb (GtkEntry *entry, GnomeDbDsnAssistant *assistant)
 {
 	const gchar *name;
 	gboolean page_complete = TRUE;
-	GdaDataSourceInfo *dsn_info;
+	GdaDsnInfo *dsn_info;
 
 	/* check required fields have values */
 	name = gtk_entry_get_text (GTK_ENTRY (assistant->priv->general_name));
@@ -308,7 +308,7 @@ dsn_name_changed_cb (GtkEntry *entry, GnomeDbDsnAssistant *assistant)
 		page_complete = FALSE;
 	}
 
-	dsn_info = gda_config_get_dsn (name);
+	dsn_info = gda_config_get_dsn_info (name);
 	if (dsn_info) {
 		gint i = 2;
 		gchar *str = NULL;
@@ -316,7 +316,7 @@ dsn_name_changed_cb (GtkEntry *entry, GnomeDbDsnAssistant *assistant)
 		do {
 			g_free (str);
 			str = g_strdup_printf ("%s_%d", name, i);
-			dsn_info = gda_config_get_dsn (str);
+			dsn_info = gda_config_get_dsn_info (str);
 		} while (dsn_info);
 
 		gtk_entry_set_text (entry, str);
@@ -413,7 +413,7 @@ gnome_db_dsn_assistant_init (GnomeDbDsnAssistant *assistant,
 
 	/* create private structure */
 	assistant->priv = g_new0 (GnomeDbDsnAssistantPrivate, 1);
-	assistant->priv->dsn_info = g_new0 (GdaDataSourceInfo, 1);
+	assistant->priv->dsn_info = g_new0 (GdaDsnInfo, 1);
 	assistant->priv->provider_detail = NULL;
 	assistant->priv->create_db_op = NULL;
 
@@ -723,9 +723,9 @@ gnome_db_dsn_assistant_new (void)
  *
  * Returns:
  */
-const GdaDataSourceInfo *
+const GdaDsnInfo *
 gnome_db_dsn_assistant_get_dsn (GnomeDbDsnAssistant *assistant)
 {
 	g_return_val_if_fail (GNOME_DB_IS_DSN_ASSISTANT (assistant), NULL);
-	return (const GdaDataSourceInfo *) assistant->priv->dsn_info;
+	return (const GdaDsnInfo *) assistant->priv->dsn_info;
 }
