@@ -381,7 +381,7 @@ gnome_db_raw_form_set_property (GObject *object,
 				form->priv->model = gda_data_proxy_get_proxied_model (form->priv->proxy);
 
 				form->priv->iter = gda_data_model_create_iter ((GdaDataModel *) form->priv->proxy);
-				gda_data_model_iter_move_at_row (form->priv->iter, 0);
+				gda_data_model_iter_move_to_row (form->priv->iter, 0);
 
 				g_signal_connect (form->priv->iter, "validate-set",
 						  G_CALLBACK (iter_validate_set_cb), form);
@@ -473,16 +473,10 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawForm *form)
 		gint i;
 
 		for (i = 0, params = ((GdaSet *) iter)->holders; params; i++, params = params->next) {
-			gboolean explicit_hide = FALSE;
 			param = (GdaHolder *) params->data;
 			attributes = gda_data_proxy_get_value_attributes (form->priv->proxy, row, i);
 			gnome_db_basic_form_entry_set_editable ((GnomeDbBasicForm *) form, 
 								param, !(attributes & GDA_VALUE_ATTR_NO_MODIF));
-			if (GPOINTER_TO_INT (g_object_get_data (G_OBJECT (param), "_gnome_db_explicit_show")) == 1)
-				explicit_hide = TRUE;
-			if (!explicit_hide) 
-				gnome_db_basic_form_entry_show ((GnomeDbBasicForm *) form, 
-								param, !(attributes & GDA_VALUE_ATTR_UNUSED));
 		}
 	}
 }
@@ -508,7 +502,7 @@ proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GnomeDbRawForm
 {
 	if (gda_data_model_get_n_rows (GDA_DATA_MODEL (form->priv->proxy)) != 0)
 		if (gda_data_model_iter_get_row (form->priv->iter) == -1)
-			gda_data_model_iter_move_at_row (form->priv->iter, row > 0 ? row - 1 : 0);
+			gda_data_model_iter_move_to_row (form->priv->iter, row > 0 ? row - 1 : 0);
 }
 
 /*
@@ -517,8 +511,6 @@ proxy_row_inserted_or_removed_cb (GdaDataProxy *proxy, gint row, GnomeDbRawForm
 static void 
 gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTable *box_widgets)
 {
-	GSList *list;
-
 	/*
 	 * handling of the layout
 	 */
@@ -552,18 +544,6 @@ gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTabl
 	if (!layout && gda_data_proxy_is_read_only (form->priv->proxy))
 		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (form), FALSE);
 
-	for (list = GDA_SET (form->priv->iter)->holders; list; list = list->next) {
-		GdaSetNode *node;
-
-		node = gda_set_get_node (GDA_SET (form->priv->iter), GDA_HOLDER (list->data));
-		g_assert (node);
-		if (node->hint &GDA_SET_HOLDER_HIDE) {
-			gnome_db_basic_form_entry_show (GNOME_DB_BASIC_FORM (form),
-							GDA_HOLDER (list->data), FALSE);
-			g_object_set_data (G_OBJECT (list->data), "_gnome_db_explicit_show", GINT_TO_POINTER (1));
-		}
-	}
-
 	/* data display update */
 	proxy_changed_cb (form->priv->proxy, form);
 }
@@ -593,7 +573,7 @@ action_new_cb (GtkAction *action, GnomeDbRawForm *form)
 		return;
 	}
 
-	g_assert (gda_data_model_iter_move_at_row (form->priv->iter, newrow));
+	g_assert (gda_data_model_iter_move_to_row (form->priv->iter, newrow));
 
 	/* set parameters to their default values */
 	list = GDA_SET (form->priv->iter)->holders;
@@ -669,7 +649,7 @@ action_commit_cb (GtkAction *action, GnomeDbRawForm *form)
 					      actually succedded the commit 
 					      => we need to come back to that row
 					   */
-				gda_data_model_iter_move_at_row (form->priv->iter, row);
+				gda_data_model_iter_move_to_row (form->priv->iter, row);
 		}
 	}
 	else
@@ -905,7 +885,7 @@ arrow_actions_real_do (GnomeDbRawForm *form, gint movement)
 	}
 
 	if (oldrow != row)
-		gda_data_model_iter_move_at_row (form->priv->iter, row);
+		gda_data_model_iter_move_to_row (form->priv->iter, row);
 }
 
 /*
@@ -936,7 +916,6 @@ gnome_db_raw_form_col_set_show (GnomeDbDataWidget *iface, gint column, gboolean
 	param = gda_data_model_iter_get_holder_for_field (form->priv->iter, column);
 	g_return_if_fail (param);
 	gnome_db_basic_form_entry_show (GNOME_DB_BASIC_FORM (form), param, shown);
-	g_object_set_data (G_OBJECT (param), "_gnome_db_explicit_show", GINT_TO_POINTER (shown ? 2 : 1));
 }
 
 void
