@@ -31,10 +31,10 @@
 static GtkStockItem builtin_icons [] = {
 	{ GNOME_DB_STOCK_AGGREGATES, N_("Aggregates"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_COMMIT, N_("Commit"), 0, 0, GETTEXT_PACKAGE },
-	{ GNOME_DB_STOCK_CONNECT, N_("Connect"), 0, 0, GETTEXT_PACKAGE },
+	{ GNOME_DB_STOCK_CONNECT, N_("Open connection"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_DATABASE, N_("Database"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_DESIGNER, N_("Designer"), 0, 0, GETTEXT_PACKAGE },
-	{ GNOME_DB_STOCK_DISCONNECT, N_("Disconnect"), 0, 0, GETTEXT_PACKAGE },
+	{ GNOME_DB_STOCK_DISCONNECT, N_("Close connection"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_NO_TRANSACTION, N_("NoTransaction"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_PROCEDURES, N_("Procedures"), 0, 0, GETTEXT_PACKAGE },
 	{ GNOME_DB_STOCK_QUERY, N_("Query"), 0, 0, GETTEXT_PACKAGE },
@@ -218,7 +218,7 @@ gnome_db_stock_get_icon_path (const gchar *stock_id)
 	gchar *file, *path;
 
 	g_return_val_if_fail (stock_id != NULL, NULL);
-	file = g_strdup_printf ("%s_24x24.png", stock_id);
+	file = g_strdup_printf ("%s_16x16.png", stock_id);
 	path = gnome_db_gbr_get_icon_path (file);
 	g_free (file);
 
