@@ -939,7 +939,7 @@ build_form_test_for_gtype (GdaDataHandler *dh, GType type, const gchar *plugin_n
 		param = plist->holders->data;
 
 		value = gda_value_new_from_string (plugin_name, G_TYPE_STRING);
-		gda_holder_set_attribute (param, GNOME_DB_ATTRIBUTE_PLUGIN, value);
+		gda_holder_set_attribute_static (param, GNOME_DB_ATTRIBUTE_PLUGIN, value);
 		gda_value_free (value);
 		g_object_unref (datawid);
 	}
@@ -975,7 +975,7 @@ build_grid_test_for_gtype (GdaDataHandler *dh, GType type, const gchar *plugin_n
 		param = plist->holders->data;
 
 		value = gda_value_new_from_string (plugin_name, G_TYPE_STRING);
-		gda_holder_set_attribute (param, GNOME_DB_ATTRIBUTE_PLUGIN, value);
+		gda_holder_set_attribute_static (param, GNOME_DB_ATTRIBUTE_PLUGIN, value);
 		gda_value_free (value);
 		g_object_unref (datawid);
 	}
